Installation
============

Requirements
------------

- Python >= 3.10
- locust >= 2.37.0
- python-json-logger >= 3.3.0


Install
-------

Using **pip**:

.. code-block:: bash

   pip install locust-telemetry

Using **uv**:

.. code-block:: bash

   uv install locust-telemetry

Using **poetry**:

.. code-block:: bash

   poetry add locust-telemetry


Verify installation
-------------------

.. code-block:: bash

   pip show locust-telemetry
